"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const Logger_1 = __importDefault(require("../Logger"));
const Database_1 = __importDefault(require("../db/Database"));
const SwapRepository_1 = __importDefault(require("../service/SwapRepository"));
const ReverseSwapRepository_1 = __importDefault(require("../service/ReverseSwapRepository"));
const Utils_1 = require("../Utils");
const CommandHandler_1 = require("../notifications/CommandHandler");
exports.generateReport = (argv) => __awaiter(this, void 0, void 0, function* () {
    // Get the path to the database from the command line arguments or
    // use the default one if none was specified
    const dbPath = argv.dbpath || '~/.boltz-middleware/boltz.db';
    const db = new Database_1.default(Logger_1.default.disabledLogger, Utils_1.resolveHome(dbPath));
    yield db.init();
    const swapRepository = new SwapRepository_1.default();
    const reverseSwapRepository = new ReverseSwapRepository_1.default();
    const { swaps, reverseSwaps } = yield CommandHandler_1.getSuccessfulTrades(swapRepository, reverseSwapRepository);
    const entries = swapsToEntries(swaps, reverseSwaps);
    entries.sort((a, b) => {
        return a.date.getTime() - b.date.getTime();
    });
    const csv = arrayToCsv(entries);
    if (argv.reportpath) {
        fs_1.default.writeFileSync(Utils_1.resolveHome(argv.reportpath), csv);
    }
    else {
        console.log(csv);
    }
});
const swapsToEntries = (swaps, reverseSwaps) => {
    const entries = [];
    const pushToEntries = (array, isReverse) => {
        array.forEach((swap) => {
            entries.push({
                date: new Date(swap.createdAt),
                pair: swap.pair,
                type: getSwapType(swap.orderSide, isReverse),
                orderSide: swap.orderSide === 0 ? 'buy' : 'sell',
                fee: Utils_1.satoshisToCoins(swap.fee).toFixed(8),
                feeCurrency: Utils_1.getFeeSymbol(swap.pair, swap.orderSide, isReverse),
            });
        });
    };
    pushToEntries(swaps, false);
    pushToEntries(reverseSwaps, true);
    return entries;
};
const getSwapType = (orderSide, isReverse) => {
    if ((orderSide === 0 && !isReverse) || (orderSide !== 0 && isReverse)) {
        return 'Lightning/Chain';
    }
    else {
        return 'Chain/Lightning';
    }
};
const arrayToCsv = (entries) => {
    const lines = [];
    if (entries.length !== 0) {
        const keys = Object.keys(entries[0]);
        lines.push(keys.join(','));
    }
    entries.forEach((entry) => {
        const date = entry.date.toLocaleString('en-US', { hour12: false }).replace(',', '');
        lines.push(`${date},${entry.pair},${entry.type},${entry.orderSide},${entry.fee},${entry.feeCurrency}`);
    });
    return lines.join('\n');
};
//# sourceMappingURL=Report.js.map